@@ -5,10 +5,10 @@ package Stable::Module;
 #
 # http://search.cpan.org/dist/Stable-Module/
 #
-# Copyright (c) 2014 INABA Hitoshi <ina@cpan.org>
+# Copyright (c) 2014, 2016 INABA Hitoshi <ina@cpan.org>
 ######################################################################
 
-$Stable::Module::VERSION = 0.02;
+$Stable::Module::VERSION = 0.03;
 
 use 5.00503;
 use strict;
@@ -165,10 +165,10 @@ sub import {
     *{$caller.'::sum'}     = sub { _reduce { $a +  $b }           @_ };
 
     # use List::MoreUtils qw(all any none notall uniq);
-    *{$caller.'::all'}    = sub { $_ || return 0 for @_; 1 }; # All arguments are true
-    *{$caller.'::any'}    = sub { $_ && return 1 for @_; 0 }; # One argument is true
-    *{$caller.'::none'}   = sub { $_ && return 0 for @_; 1 }; # All arguments are false
-    *{$caller.'::notall'} = sub { $_ || return 1 for @_; 0 }; # One argument is false
+    *{$caller.'::all'}    = sub { _reduce {  $a &&  $b } @_ }; # All arguments are true
+    *{$caller.'::any'}    = sub { _reduce {  $a ||  $b } @_ }; # One argument is true
+    *{$caller.'::none'}   = sub { _reduce { !$a && !$b } @_ }; # All arguments are false
+    *{$caller.'::notall'} = sub { _reduce { !$a || !$b } @_ }; # One argument is false
     *{$caller.'::uniq'}   = \&_uniq;
 
     # use feature qw(say);
